import{r as i,j as r}from"./@radix-3bj3otF9.js";import{R as a}from"./ButtonGroup-6mvBi1qZ.js";import{a4 as m}from"./index-1REJ-mbf.js";import{u as n,g as p,R as u,P as c}from"./service-BeM81Fmj.js";import{a as l}from"./@react-router-Ct_TgVUW.js";import"./trash-B0fyghWi.js";import"./AlertDialogDropdownItem-CAlqlfdb.js";import"./DeleteAlertDialog-BUIIlTob.js";import"./zod-36FJuF1H.js";import"./index.esm-DnoyTjte.js";import"./helper-BXlR2ZLp.js";import"./delete-run-CXwbsSWi.js";import"./@tanstack-CByuvRcg.js";import"./bulk-delete-C0Pqi-YB.js";import"./@reactflow-CwWcBchH.js";import"./refresh-BaK7e0kN.js";import"./SearchField-CjwYvxg3.js";import"./index-FwZ5fdjO.js";import"./all-pipeline-runs-query-CzIJhvJX.js";import"./Pagination-DePVp3ki.js";import"./chevron-right-double-BuLe9bCa.js";function d(e){const{setBreadcrumbs:t}=m();i.useEffect(()=>{},[t,e])}function x(){const{pipelineId:e}=l(),t=n(),o=i.useMemo(()=>p(),[]),s={pipeline_id:e,...t,sort_by:"desc:updated"};return r.jsxs(r.Fragment,{children:[r.jsx(u,{params:s}),r.jsx(c,{columns:o,params:s})]})}function q(){return d(),r.jsx("div",{className:"space-y-5",children:r.jsx(a,{children:r.jsx(x,{})})})}export{q as default};
