import{H as n,K as r,ag as a,E as u,ai as i,J as o}from"./index-1REJ-mbf.js";import{b as c}from"./@tanstack-CByuvRcg.js";function l({params:e}){return["runs",e]}async function p({params:e}){const s=n(r.runs.all+"?"+a(e)),t=await u(s,{method:"GET",headers:{"Content-Type":"application/json"}});if(t.status===404&&i(),!t.ok)throw new o({message:"Error while fetching pipeline runs",status:t.status,statusText:t.statusText});return t.json()}function y(e,s){return c({queryKey:l(e),queryFn:()=>p(e),...s})}export{y as u};
