import{j as t}from"./@radix-3bj3otF9.js";import{C as o,S as r}from"./StackComponentList-Cixkr5Pq.js";import"./plus-Cewn_igr.js";import"./refresh-BaK7e0kN.js";import"./Pagination-DePVp3ki.js";import"./index-1REJ-mbf.js";import"./@tanstack-CByuvRcg.js";import"./@react-router-Ct_TgVUW.js";import"./@reactflow-CwWcBchH.js";import"./chevron-right-double-BuLe9bCa.js";import"./SearchField-CjwYvxg3.js";import"./index-FwZ5fdjO.js";import"./expand-full-HjUlDE5L.js";import"./SheetHeader-D7LxTrv6.js";import"./Tabs-DnNiHAEK.js";import"./chevron-down-smmnLxYI.js";import"./transform-CRpCHU_K.js";import"./KeyValue-ULVVsU7P.js";import"./eye-vFb-iYpN.js";import"./CollapsibleCard-eUpjksBv.js";import"./CodeSnippet-LBT7JnAL.js";import"./all-pipeline-runs-query-CzIJhvJX.js";import"./index-iuK9vGP1.js";import"./stack-detail-query-DK_ie4nm.js";import"./ComponentBadge-CYC6mnh8.js";import"./ComponentIcon-ilWLl5Ys.js";import"./bar-chart-square-check-Diki0CFQ.js";import"./layout-zVxDzB0C.js";import"./trash-B0fyghWi.js";import"./DeleteAlertDialog-BUIIlTob.js";import"./zod-36FJuF1H.js";import"./index.esm-DnoyTjte.js";import"./Infobox-D1YtF5f6.js";import"./helper-BXlR2ZLp.js";import"./bulk-delete-C0Pqi-YB.js";function H(){return t.jsx("div",{className:"pt-5",children:t.jsx(o,{children:t.jsx(r,{})})})}export{H as default};
