import{j as r}from"./@radix-3bj3otF9.js";import{R as o}from"./RunsBody-C9kkBKa3.js";import{R as t}from"./ButtonGroup-6mvBi1qZ.js";import"./refresh-BaK7e0kN.js";import"./Pagination-DePVp3ki.js";import"./index-1REJ-mbf.js";import"./@tanstack-CByuvRcg.js";import"./@react-router-Ct_TgVUW.js";import"./@reactflow-CwWcBchH.js";import"./chevron-right-double-BuLe9bCa.js";import"./SearchField-CjwYvxg3.js";import"./index-FwZ5fdjO.js";import"./all-pipeline-runs-query-CzIJhvJX.js";import"./pipeline-link-f7nbs-No.js";import"./trash-B0fyghWi.js";import"./AlertDialogDropdownItem-CAlqlfdb.js";import"./DeleteAlertDialog-BUIIlTob.js";import"./zod-36FJuF1H.js";import"./index.esm-DnoyTjte.js";import"./helper-BXlR2ZLp.js";import"./delete-run-CXwbsSWi.js";import"./bulk-delete-C0Pqi-YB.js";function E(){return r.jsx(t,{children:r.jsx(o,{})})}export{E as default};
